@@ -99,6 +99,10 @@ class Term {
     ASSERT(offset < _varCount);
     return _exponents[offset];
   }
+  Exponent operator[](unsigned long long offset) const {
+    ASSERT(offset < _varCount);
+    return _exponents[offset];
+  }
 
   Exponent& operator[](int offset) {
     ASSERT(0 <= offset);
@@ -113,6 +117,10 @@ class Term {
     ASSERT(offset < _varCount);
     return _exponents[offset];
   }
+  Exponent& operator[](unsigned long long offset) {
+    ASSERT(offset < _varCount);
+    return _exponents[offset];
+  }
 
   bool operator==(const Term& term) const {
     ASSERT(_varCount == term._varCount);
